package VMOMI::BaseConfigInfoDiskFileBackingInfoProvisioningType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
